@@ -19,7 +19,7 @@ import builtins
 
 import numpy as np
 
-from astropy.utils.compat import NUMPY_LT_1_22
+from astropy.utils.compat import NUMPY_LT_2_0
 from astropy.utils.data_info import ParentDtypeInfo
 from astropy.utils.shapes import NDArrayShapeMethods
 
@@ -513,6 +513,12 @@ class MaskedNDArray(Masked, np.ndarray, base_cls=np.ndarray, data_cls=np.ndarray
     def from_unmasked(cls, data, mask=None, copy=False):
         # Note: have to override since __new__ would use ndarray.__new__
         # which expects the shape as its first argument, not an array.
+
+        if not NUMPY_LT_2_0 and copy is False:
+            # strict backward compatibility
+            # see https://github.com/astropy/astropy/pull/16142
+            copy = None
+
         data = np.array(data, subok=True, copy=copy)
         self = data.view(cls)
         self._set_mask(mask, copy=copy)
@@ -697,7 +703,9 @@ class MaskedNDArray(Masked, np.ndarray, base_cls=np.ndarray, data_cls=np.ndarray
                 np.copyto(out, masks[0], where=where)
                 return out
 
-        out = np.logical_or(masks[0], masks[1], out=out, where=where)
+        # [...] at the end to ensure we have an array, not a scalar, and
+        # thus can be used for in-place changes in the loop.
+        out = np.logical_or(masks[0], masks[1], out=out, where=where)[...]
         for mask in masks[2:]:
             np.logical_or(out, mask, out=out, where=where)
         return out
@@ -760,10 +768,18 @@ class MaskedNDArray(Masked, np.ndarray, base_cls=np.ndarray, data_cls=np.ndarray
             else:
                 # Parse signature with private numpy function. Note it
                 # cannot handle spaces in tuples, so remove those.
-                in_sig, out_sig = np.lib.function_base._parse_gufunc_signature(
-                    ufunc.signature.replace(" ", "")
-                )
-                axis = kwargs.get("axis", -1)
+                if NUMPY_LT_2_0:
+                    in_sig, out_sig = np.lib.function_base._parse_gufunc_signature(
+                        ufunc.signature.replace(" ", "")
+                    )
+                else:
+                    (
+                        in_sig,
+                        out_sig,
+                    ) = np.lib._function_base_impl._parse_gufunc_signature(
+                        ufunc.signature.replace(" ", "")
+                    )
+                axis = kwargs.get("axis")
                 keepdims = kwargs.get("keepdims", False)
                 in_masks = []
                 for sig, mask in zip(in_sig, masks):
@@ -773,8 +789,13 @@ class MaskedNDArray(Masked, np.ndarray, base_cls=np.ndarray, data_cls=np.ndarray
                             # value in those is masked, the output will be
                             # masked too (TODO: for multiple core dimensions
                             # this may be too strong).
+                            in_axis = (
+                                tuple(range(-1, -1 - len(sig), -1))
+                                if axis is None
+                                else axis
+                            )
                             mask = np.logical_or.reduce(
-                                mask, axis=axis, keepdims=keepdims
+                                mask, axis=in_axis, keepdims=keepdims
                             )
                         in_masks.append(mask)
 
@@ -784,7 +805,10 @@ class MaskedNDArray(Masked, np.ndarray, base_cls=np.ndarray, data_cls=np.ndarray
                     if os:
                         # Output has core dimensions.  Assume all those
                         # get the same mask.
-                        result_mask = np.expand_dims(mask, axis)
+                        out_axis = (
+                            tuple(range(-1, -1 - len(os), -1)) if axis is None else axis
+                        )
+                        result_mask = np.expand_dims(mask, out_axis)
                     else:
                         result_mask = mask
                     result_masks.append(result_mask)
@@ -893,8 +917,8 @@ class MaskedNDArray(Masked, np.ndarray, base_cls=np.ndarray, data_cls=np.ndarray
             except NotImplementedError:
                 return self._not_implemented_or_raise(function, types)
 
-            if not isinstance(dispatched_result, tuple):
-                return dispatched_result
+            if dispatched_result is None:
+                return None
 
             result, mask, out = dispatched_result
 
@@ -918,8 +942,8 @@ class MaskedNDArray(Masked, np.ndarray, base_cls=np.ndarray, data_cls=np.ndarray
         # it quite likely coerces, so we should just break.
         if any(issubclass(t, np.ndarray) and not issubclass(t, Masked) for t in types):
             raise TypeError(
-                "the MaskedNDArray implementation cannot handle {} "
-                "with the given arguments.".format(function)
+                f"the MaskedNDArray implementation cannot handle {function} "
+                "with the given arguments."
             ) from None
         else:
             return NotImplemented
@@ -982,6 +1006,11 @@ class MaskedNDArray(Masked, np.ndarray, base_cls=np.ndarray, data_cls=np.ndarray
             axis=axis, out=out, **self._reduce_defaults(kwargs, np.nanmin)
         )
 
+    def ptp(self, axis=None, out=None, **kwargs):
+        result = self.max(axis=axis, out=out, **kwargs)
+        result -= self.min(axis=axis, **kwargs)
+        return result
+
     def nonzero(self):
         unmasked_nonzero = self.unmasked.nonzero()
         if self.ndim >= 1:
@@ -1002,31 +1031,17 @@ class MaskedNDArray(Masked, np.ndarray, base_cls=np.ndarray, data_cls=np.ndarray
         # Let __array_function__ take care since choices can be masked too.
         return np.choose(self, choices, out=out, mode=mode)
 
-    if NUMPY_LT_1_22:
+    def argmin(self, axis=None, out=None, *, keepdims=False):
+        # TODO: should this return a masked integer array, with masks
+        # if all elements were masked?
+        at_min = self == self.min(axis=axis, keepdims=True)
+        return at_min.filled(False).argmax(axis=axis, out=out, keepdims=keepdims)
 
-        def argmin(self, axis=None, out=None):
-            # Todo: should this return a masked integer array, with masks
-            # if all elements were masked?
-            at_min = self == self.min(axis=axis, keepdims=True)
-            return at_min.filled(False).argmax(axis=axis, out=out)
+    def argmax(self, axis=None, out=None, *, keepdims=False):
+        at_max = self == self.max(axis=axis, keepdims=True)
+        return at_max.filled(False).argmax(axis=axis, out=out, keepdims=keepdims)
 
-        def argmax(self, axis=None, out=None):
-            at_max = self == self.max(axis=axis, keepdims=True)
-            return at_max.filled(False).argmax(axis=axis, out=out)
-
-    else:
-
-        def argmin(self, axis=None, out=None, *, keepdims=False):
-            # Todo: should this return a masked integer array, with masks
-            # if all elements were masked?
-            at_min = self == self.min(axis=axis, keepdims=True)
-            return at_min.filled(False).argmax(axis=axis, out=out, keepdims=keepdims)
-
-        def argmax(self, axis=None, out=None, *, keepdims=False):
-            at_max = self == self.max(axis=axis, keepdims=True)
-            return at_max.filled(False).argmax(axis=axis, out=out, keepdims=keepdims)
-
-    def argsort(self, axis=-1, kind=None, order=None):
+    def argsort(self, axis=-1, kind=None, order=None, *, stable=None):
         """Returns the indices that would sort an array.
 
         Perform an indirect sort along the given axis on both the array
@@ -1044,6 +1059,8 @@ class MaskedNDArray(Masked, np.ndarray, base_cls=np.ndarray, data_cls=np.ndarray
             second, etc.  A single field can be specified as a string, and not
             all fields need be specified, but unspecified fields will still be
             used, in dtype order, to break ties.
+        stable: bool, keyword-only, ignored
+            Sort stability. Present only to allow subclasses to work.
 
         Returns
         -------
@@ -1063,8 +1080,10 @@ class MaskedNDArray(Masked, np.ndarray, base_cls=np.ndarray, data_cls=np.ndarray
             # As done inside the argsort implementation in multiarray/methods.c.
             if order is None:
                 order = self.dtype.names
-            else:
+            elif NUMPY_LT_2_0:
                 order = np.core._internal._newnames(self.dtype, order)
+            else:
+                order = np._core._internal._newnames(self.dtype, order)
 
             keys = tuple(data[name] for name in order[::-1])
 
@@ -1076,10 +1095,20 @@ class MaskedNDArray(Masked, np.ndarray, base_cls=np.ndarray, data_cls=np.ndarray
 
         return np.lexsort(keys, axis=axis)
 
-    def sort(self, axis=-1, kind=None, order=None):
-        """Sort an array in-place. Refer to `numpy.sort` for full documentation."""
+    def sort(self, axis=-1, kind=None, order=None, *, stable=False):
+        """Sort an array in-place. Refer to `numpy.sort` for full documentation.
+
+        Notes
+        -----
+        Masked items will be sorted to the end. The implementation
+        is via `numpy.lexsort` and thus ignores the ``kind`` and ``stable`` arguments;
+        they are present only so that subclasses can pass them on.
+        """
         # TODO: probably possible to do this faster than going through argsort!
-        indices = self.argsort(axis, kind=kind, order=order)
+        argsort_kwargs = dict(kind=kind, order=order)
+        if not NUMPY_LT_2_0:
+            argsort_kwargs["stable"] = stable
+        indices = self.argsort(axis, **argsort_kwargs)
         self[:] = np.take_along_axis(self, indices, axis=axis)
 
     def argpartition(self, kth, axis=-1, kind="introselect", order=None):
